@@ -29,9 +29,9 @@ from myFunctions2 import * #Own functions
 
 #GUIs
 from Ui_StartWindow import *
-from Ui_CollectingWindow import *
-from Ui_LogWindow import *
-from Ui_NoteWindow import *
+from Ui_RecordWindow import *
+from Ui_ViewWindow import *
+
 
 
 
@@ -40,9 +40,9 @@ from Ui_NoteWindow import *
 # Main function
 ###########################################################################
 def main():
-    global app,  StartWindow,  CollectingWindow,  LogWindow ,  NoteWindow
+    global app,  StartWindow,  RecordWindow,  ViewWindow 
     global config
-    global CollectingWindowGraph
+    global RecordWindowGraph
    
     try:
         if(sys.argv[1]=="debug"): 
@@ -70,9 +70,8 @@ def main():
     else: data.app_path=data.app_path+"/"
     
     StartWindow = frmStartWindow()    
-    CollectingWindow = frmCollectingWindow()
-    LogWindow = frmLogWindow()
-    NoteWindow = frmNoteWindow()
+    RecordWindow = frmRecordWindow()
+    ViewWindow = frmViewWindow()
     
     StartWindow.show()      
 
@@ -102,7 +101,7 @@ def main():
 #  Gets called every second,
 ###########################################################################
 def TimerLoop():
-    global CollectingWindowGraph
+    global RecordWindowGraph
     
 #    Show_passed_time("TimerLoop start")
 
@@ -111,9 +110,9 @@ def TimerLoop():
         WriteIntoLogFile()
         ProcessData() 
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
-        CollectingWindowGraph.update() #show CollectingWindowGraph    
+        RecordWindowGraph.update() #show RecordWindowGraph    
     
-    CollectingWindow.UpdateScreen()    
+    RecordWindow.UpdateScreen()    
     
 #    Show_passed_time("TimerLoop end")
 
@@ -180,13 +179,13 @@ def StopMeasurement():
 def Zoom(direction):
     if(direction==+1): #zoom in
         if(data.Xscale==0): return
-        LogWindow.ui.bZoomOut.setEnabled(True)
+        ViewWindow.ui.bZoomOut.setEnabled(True)
         data.Xscale=(data.Xscale-1) % data.arrXscaleLen
         ProcessData()
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
     else: # -1, zoom out
         if(data.Xscale==data.arrXscaleLen-1): return
-        LogWindow.ui.bZoomIn.setEnabled(True)
+        ViewWindow.ui.bZoomIn.setEnabled(True)
         data.Xscale=(data.Xscale+1) % data.arrXscaleLen
         ProcessData()
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
@@ -230,7 +229,13 @@ class frmStartWindow(QtGui.QWidget):
 
         QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), self.StartMeasurementNormal)
         QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), self.StartMeasurementQuick)
-        QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), self.ShowLogWindow)
+        QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), self.ShowViewWindow)
+        
+        file = open(data.app_path+"Info.htm", 'r')
+        txt=""
+        for line in file: txt=txt+line+"\n"
+        file.close()
+        self.ui.textBrowser.setHtml(txt)
         
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"SleepAnalyser.png"))
@@ -259,20 +264,20 @@ class frmStartWindow(QtGui.QWidget):
         
         
     def StartMeasurement(self):
-        global CollectingWindowGraph
-        CollectingWindow.show()
+        global RecordWindowGraph
+        RecordWindow.show()
         StartWindow.hide()
-        CollectingWindowGraph = CollectingWindowCanvas()
+        RecordWindowGraph = RecordWindowCanvas()
         StartMeasurement()
-        CollectingWindow.UpdateScreenStart()
-        CollectingWindowGraph.show()
+        RecordWindow.UpdateScreenStart()
+        RecordWindowGraph.show()
         
         
     ###########################################################################
     # Show the log window (her ethe data from a file gets visualised)
     ###########################################################################
-    def ShowLogWindow(self):
-        global LogWindowGraph
+    def ShowViewWindow(self):
+        global ViewWindowGraph
         
         if os.path.exists(data.logfolder+data.lastlogfile):
             data.logfilename=data.lastlogfile
@@ -291,10 +296,10 @@ class frmStartWindow(QtGui.QWidget):
         
         print data.logfilename
         
-        LogWindowGraph = LogWindowCanvas()
-        LogWindow.ShowLogFile()
+        ViewWindowGraph = ViewWindowCanvas()
+        ViewWindow.ShowLogFile()
         
-        LogWindow.show()
+        ViewWindow.show()
         StartWindow.hide()
         
         
@@ -333,10 +338,10 @@ class frmStartWindow(QtGui.QWidget):
 ###########################################################################
 #  Class for Collecting Window
 ###########################################################################
-class frmCollectingWindow(QtGui.QWidget):
+class frmRecordWindow(QtGui.QWidget):
     def __init__(self, parent=None):
         QtGui.QWidget.__init__(self, parent)
-        self.ui = Ui_CollectingWindow()
+        self.ui = Ui_RecordWindow()
         self.ui.setupUi(self)
         
         QtCore.QObject.connect(self.ui.bStop, QtCore.SIGNAL("clicked()"), self.ToggleMeasurement)
@@ -362,7 +367,7 @@ class frmCollectingWindow(QtGui.QWidget):
         time_difference=t-data.StartTimeSec
         t=strftime("%H:%M:%S", time.gmtime(time_difference))
         self.ui.lblElapsedTime.setText(t)
-        self.ui.lblTrigger.setText(str(data.trigger))
+#        self.ui.lblTrigger.setText(str(data.trigger))
         
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -381,8 +386,8 @@ class frmCollectingWindow(QtGui.QWidget):
         self.ui.lblStarttime.setText(t)
         self.ui.lblSamples_Taken.setText("0")
         self.ui.lblElapsedTime.setText("00:00:00")
-        self.ui.lblYscale.setText(str(data.Yscale))
-        self.ui.lblTrigger.setText(str(data.trigger))
+#        self.ui.lblYscale.setText(str(data.Yscale))
+#        self.ui.lblTrigger.setText(str(data.trigger))
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
         self.ui.bStop.setIcon(QIcon(data.app_path+"krec2.png"))
         self.ui.bStop.setText("Stop recording")
@@ -456,7 +461,6 @@ class frmCollectingWindow(QtGui.QWidget):
         #in case measurement is still running (user did not click on "stop")
         if(data.run==1): StopMeasurement()
         StartWindow.show()
-#        NoteWindow.show()
         self.close() 
 
 
@@ -471,10 +475,10 @@ class frmCollectingWindow(QtGui.QWidget):
 ###########################################################################
 # Class for Log Window
 ###########################################################################
-class frmLogWindow(QtGui.QWidget):
+class frmViewWindow(QtGui.QWidget):
     def __init__(self, parent=None):
         QtGui.QWidget.__init__(self, parent)
-        self.ui = Ui_LogWindow()
+        self.ui = Ui_ViewWindow()
         self.ui.setupUi(self)
         
         QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
@@ -486,26 +490,33 @@ class frmLogWindow(QtGui.QWidget):
         QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), self.DeleteLogFile)
         QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.Open)
         QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
+        QtCore.QObject.connect(self.ui.bLeft, QtCore.SIGNAL("clicked()"), self.goLeft)
+        QtCore.QObject.connect(self.ui.bRight, QtCore.SIGNAL("clicked()"), self.goRight)
+        
+        self.ui.bLeft.hide() #not yet used
+        self.ui.bRight.hide() #not yet used
         
         if(data.app_path!="./"): #only needed if not started in app path
-            self.ui.bLast.setIcon(QIcon(data.app_path+"go-previous.png"))
-            self.ui.bNext.setIcon(QIcon(data.app_path+"go-next.png"))
+            self.ui.bLast.setIcon(QIcon(data.app_path+"arrow-left-double.png"))
+            self.ui.bNext.setIcon(QIcon(data.app_path+"arrow-right-double.png"))
             self.ui.bDelete.setIcon(QIcon(data.app_path+"edittrash.png"))
-            self.ui.bOpen.setIcon(QIcon(data.app_path+"zoom.png"))
+            self.ui.bOpen.setIcon(QIcon(data.app_path+"document-open-folder.png"))
             self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
             self.ui.bZoomOut.setIcon(QIcon(data.app_path+"zoom-out.png"))
             self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"go-up.png"))
             self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"go-down.png"))
+            self.ui.bLeft.setIcon(QIcon(data.app_path+"go-previous.png"))
+            self.ui.bRight.setIcon(QIcon(data.app_path+"go-next.png"))
             
-        self.ui.lblYscale.setText(str(data.Yscale))
+#        self.ui.lblYscale.setText(str(data.Yscale))
 
 
     def UpdateScreen(self):
         self.ui.lblLogfile.setText(data.logfilename)
         self.ui.lblStarttime.setText(str(data.arrData[0][0]))
         self.ui.lblStoptime.setText(str(data.arrData[0][data.arrDataIndex-1]))
-        self.ui.lblTrigger.setText(str(data.trigger))
-        self.ui.lblYscale.setText(str(data.Yscale))
+#        self.ui.lblTrigger.setText(str(data.trigger))
+#        self.ui.lblYscale.setText(str(data.Yscale))
         self.ui.lblNote.setText(str(data.Note))
 
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
@@ -526,10 +537,9 @@ class frmLogWindow(QtGui.QWidget):
         ProcessData()
         data.Xscale=1 #default zoom level
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
-        LogWindowGraph = LogWindowCanvas()
-        LogWindowGraph.show()
+        ViewWindowGraph = ViewWindowCanvas()
+        ViewWindowGraph.show()
         self.UpdateScreen()
-#        data.ChangedNote=0
         
         
     def NextLogFile(self):
@@ -563,20 +573,21 @@ class frmLogWindow(QtGui.QWidget):
 
     def RaiseTrigger(self):   
         MoveTrigger(+1)
-#        self.ui.bLowerTrigger.setEnabled(True)
-#        if(data.trigger==data.maxtrigger): self.ui.bRaiseTrigger.setEnabled(False)
-#        else: self.ui.bRaiseTrigger.setEnabled(True)
         self.update() 
         self.UpdateScreen()
         
     def LowerTrigger(self):     
         MoveTrigger(-1)
-#        self.ui.bRaiseTrigger.setEnabled(True)
-#        if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
-#        else: self.ui.bLowerTrigger.setEnabled(True)
         self.update()
         self.UpdateScreen()
-   
+        
+        
+    def goLeft(self):
+        pass
+        
+    def goRight(self):
+        pass
+        
 
     def DeleteLogFile(self):
         reply = QtGui.QMessageBox.question(self, 'Delete Logfile?', "Are you sure you want to delete this record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
@@ -617,7 +628,7 @@ class frmLogWindow(QtGui.QWidget):
 
     def closeEvent(self, event):
         config.set('main', 'trigger', str(data.trigger))      
-        LogWindow.close()
+        ViewWindow.close()
         StartWindow.show()
 
     def EditNote(self):
@@ -635,52 +646,20 @@ class frmLogWindow(QtGui.QWidget):
 
 
 
+
+
+
+
+
+
+
+
 ###########################################################################
-# Class for Log Window
+# Class for drawing the RecordWindowGraph
 ###########################################################################
-class frmNoteWindow(QtGui.QWidget):
+class RecordWindowCanvas(QtGui.QWidget):
     def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, parent)
-        self.ui = Ui_NoteWindow()
-        self.ui.setupUi(self)
-        
-        QtCore.QObject.connect(self.ui.bClose, QtCore.SIGNAL("clicked()"), self.NotesClose)
-        QtCore.QObject.connect(self.ui.bSave, QtCore.SIGNAL("clicked()"), self.NotesSave)
-        
-        
-    def SaveNotes(self):
-        txt=""
-        if(self.ui.cFeedback1.isChecked()==true):
-            pass
-            
-    def NotesClose(self):
-        StartWindow.show()
-        NoteWindow.close()
-        
-    def NotesSave(self):
-        NoteWindow.SaveNotes()
-        NotesClose()
-
-    def closeEvent(self, event):
-        NoteWindow.close()
-        StartWindow.show()
-
-
-
-
-
-
-
-
-
-
-
-###########################################################################
-# Class for drawing the CollectingWindowGraph
-###########################################################################
-class CollectingWindowCanvas(QtGui.QWidget):
-    def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, CollectingWindow)    
+        QtGui.QWidget.__init__(self, RecordWindow)    
         self.setGeometry(9, 180, 782, data.Ysize+30)
     
     def paintEvent(self, event):
@@ -693,11 +672,11 @@ class CollectingWindowCanvas(QtGui.QWidget):
     
     
 ###########################################################################
-# Class for drawing the LogWindowGraph
+# Class for drawing the ViewWindowGraph
 ###########################################################################
-class LogWindowCanvas(QtGui.QWidget):
+class ViewWindowCanvas(QtGui.QWidget):
     def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, LogWindow)    
+        QtGui.QWidget.__init__(self, ViewWindow)    
         self.setGeometry(9, 100, 782, data.Ysize+30)
     
     def paintEvent(self, event):
